using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Runtime.Serialization;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Tools;
using System.IO;
using Syncfusion.Windows.Forms.Tools.XPMenus;

namespace TabbedMDI_2005
{
    public partial class Form1 : Office2007Form
    {
        private DemoCommon.AboutForm aboutForm = null;
        private bool tabWindowsOn = false;
        private int document1Count = 0;

        public Form1()
        {
            InitializeComponent();
            this.tabbedMDIManager = new Syncfusion.Windows.Forms.Tools.TabbedMDIManager();
            this.tabbedMDIManager.AttachedTo = this;
            this.tabbedMDIManager.DropDownButtonVisible = true;
            this.tabbedMDIManager.ImageSize = new System.Drawing.Size(16, 16);
            this.tabbedMDIManager.NeedUpdateHostedForm = false;
            this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2007);            
            this.tabbedMDIManager.TabControlAdded += new Syncfusion.Windows.Forms.Tools.TabbedMDITabControlEventHandler(this.tabbedMDIManager_TabControlAdded);
            this.groupView1.MouseMove += new MouseEventHandler(groupView1_MouseMove);            
        }

        void groupView1_MouseMove(object sender, MouseEventArgs e)
        {
            GroupView gv = sender as GroupView;
            Point pt = new Point(e.X, e.Y);
            int index = gv.GetItemUnderPoint(pt);
            Cursor cursor = Cursors.Default;
            if (index >= 0
                && gv.GroupViewItems[index].Enabled )
            {
                cursor = Cursors.Hand;
            }
            if (gv.Cursor != cursor)
            {
                gv.Cursor = cursor;
            }
            
        }

        // Convenient way to toggle TabbedMDI mode.
        internal bool TabbedMDIOn
        {
            get { return this.tabWindowsOn; }
            set
            {
                if (!(this.tabWindowsOn == value))
                {
                    this.tabWindowsOn = value;

                    if (this.tabWindowsOn)
                    {
                        this.tabbedMDIManager.AttachToMdiContainer(this);
                    }
                    else
                    {
                        this.tabbedMDIManager.DetachFromMdiContainer(this, false); // false to not invoke the Cascade mode after detaching.
                    }
                }
            }
        }

        internal TabbedMDIManager TabbedMDIManager
        {
            get { return this.tabbedMDIManager; }
        }

        private void SendMessageToStatusBar(string text)
        {
            this.statusBarAdvPanel1.Text = text;
        }

        TabControlAdv tabControl;
        // Triggered when a tabgroup host is created.
        private void tabbedMDIManager_TabControlAdded(object sender, Syncfusion.Windows.Forms.Tools.TabbedMDITabControlEventArgs args)
        {
            tabControl = args.TabControl;
            if (barItem18.Checked)
            {
                args.TabControl.Office2007ColorScheme = Office2007Theme.Blue;
            }
            else if (barItem19.Checked)
            {
                args.TabControl.Office2007ColorScheme = Office2007Theme.Black;
            }
            else if (barItem20.Checked)
            {
                args.TabControl.Office2007ColorScheme = Office2007Theme.Silver;
            }
        }

        //Add a document 
        private void AddDocument(Form doc)
        {
            doc.MdiParent = this;
            doc.Show();
            this.mdiListBarItem1.ChildCaptions.Add(doc.Name);
        }

        private void NewDocClick(object sender, EventArgs e)
        {
            document1Count++;
            Document1 doc = new Document1("Document " + document1Count.ToString());
            AddDocument(doc);

            // To set tooltip for the tabs
            this.tabbedMDIManager.SetTooltip(doc, "Tooltip for " + doc.Text);
        }


        private Syncfusion.Windows.Forms.Tools.TabbedMDIManager tabbedMDIManager;
        private void Form1_Load(object sender, EventArgs e)
        {
            // Turn on MDI Tabbed Documents mode.
            // Call this after loading the mdi children to restore their previous state.
            this.TabbedMDIOn = true;
            this.tabbedMDIManager.ContextMenuItem.Items.Add(this.closeAllBarItem);
            this.tabbedMDIManager.ContextMenuItem.BeginGroupAt(closeAllBarItem);
            this.tabbedMDIManager.ContextMenuItem.Items.Add(this.barItem1);

            if (File.Exists(@"..\..\persist.xml"))
            {
                AppStateSerializer serializer = new AppStateSerializer(SerializeMode.XMLFile, @"..\..\persist");
                this.tabbedMDIManager.LoadTabGroupStates(serializer);
                SendMessageToStatusBar("TabGroupStates loaded");
            }

            groupView1.SelectedHighlightTextColor = Color.Orange; //
        }

        private void ToggleAlign(object sender, EventArgs e)
        {
            this.tabbedMDIManager.Horizontal = !this.tabbedMDIManager.Horizontal;
        }

        private void AppExit(object sender, EventArgs e)
        {
            this.Close();
        }

        private void Parse(object sender, EventArgs e)
        {
            string children = String.Empty;
            foreach (Form form in this.tabbedMDIManager.MdiChildren)
            {
                children += form.Text + "\r\n";
            }
            MessageBox.Show(children);
        }

        private void Form1_MdiChildActivate(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild == null)
            {
                statusBarAdv1.Text = "";
            }
            else
            {
                statusBarAdv1.Text = this.ActiveMdiChild.Text;
            }
        }

        private void LoadState(object sender, EventArgs e)
        {
            AppStateSerializer serializer = new AppStateSerializer(SerializeMode.XMLFile, @"..\..\persist");
            this.tabbedMDIManager.LoadTabGroupStates(serializer);
            SendMessageToStatusBar("TabGroupStates loaded");
        }

        private void SaveState(object sender, EventArgs e)
        {
            AppStateSerializer serializer = new AppStateSerializer(SerializeMode.XMLFile, @"..\..\persist");
            this.tabbedMDIManager.SaveTabGroupStates(serializer);
            serializer.PersistNow();
            SendMessageToStatusBar("TabGroupStates saved");
        }

        private void CloseAll(object sender, EventArgs e)
        {
            foreach (Form f in this.tabbedMDIManager.MdiChildren)
            {
                if (this.ActiveMdiChild.Name != f.Name)
                    f.Close();
            }
        }

        private void ShowProperties(object sender, EventArgs e)
        {
            barItem7.Checked = !barItem7.Checked;

            //tabControlAdv1.Visible = barItem7.Checked;
            splitter1.Visible = barItem7.Checked;
        }

        private void About(object sender, EventArgs e)
        {
            aboutForm = new DemoCommon.AboutForm(AppDomain.CurrentDomain.GetAssemblies());
            aboutForm.ShowDialog();
        }

        public void MenuCheckRemove(Syncfusion.Windows.Forms.Tools.XPMenus.BarItem Item)
        {
            foreach (BarItem barItem in this.StylesList.Items)
            {
                if (barItem != Item)
                {
                    ((BarItem)barItem).Checked = false;

                }
                else
                    ((BarItem)barItem).Checked = true;
            }
        }

        // Changing the tab style.
        private void TabStyles_Click(object sender, System.EventArgs e)
        {
            this.MenuCheckRemove((BarItem)sender);

            if (this.barItem8.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRenderer2D);
            else if (this.barItem9.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRenderer3D);
            else if (this.barItem10.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererWorkbookMode);
            else if (this.barItem11.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.OneNoteStyleRenderer);
            else if (this.barItem12.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.OneNoteStyleFlatTabsRenderer);
            else if (this.barItem13.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2003);
            else if (this.barItem14.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererWhidbey);
            else if (this.barItem15.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererDockingWhidbey);
            else if (this.barItem16.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererDockingWhidbeyBeta);
            else if (this.barItem17.Checked)
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererIE7);

                // TabbedMDIManager does not have Office2007 Black and Silver them
                // Hence accessing the internal tabControlAdv and applying
                // 
            else if (this.barItem18.Checked)
            {
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2007);

                foreach (TabHost tabhost in tabbedMDIManager.TabGroupHosts)
                    tabhost.MDITabPanel.Office2007ColorScheme = Office2007Theme.Blue;

            }
            else if (this.barItem19.Checked)
            {
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2007);

                foreach (TabHost tabhost in tabbedMDIManager.TabGroupHosts)
                    tabhost.MDITabPanel.Office2007ColorScheme = Office2007Theme.Black;

            }
            else if (this.barItem20.Checked)
            {
                this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2007);

                foreach (TabHost tabhost in tabbedMDIManager.TabGroupHosts)
                    tabhost.MDITabPanel.Office2007ColorScheme = Office2007Theme.Silver;
            }
        }

        private void groupView1_GroupViewItemSelected(object sender, EventArgs e)
        {
            this.NewDocClick(sender, e);
        }    
    }
}